==> opensaml-saml-impl-3.3.1-sources.jar: org/opensaml/saml/ext/saml2mdui/impl/GeolocationHintBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.ext.saml2mdui.impl;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.saml.common.xml.SAMLConstants;
import org.opensaml.saml.ext.saml2mdui.GeolocationHint;

/**
 * Builder of {@link GeolocationHint} objects.
 */
public class GeolocationHintBuilder extends AbstractSAMLObjectBuilder<GeolocationHint> {

    /**
     * Constructor.
     */
    public GeolocationHintBuilder() {

    }

    /** {@inheritDoc} */
    public GeolocationHint buildObject() {
        return buildObject(SAMLConstants.SAML20MDUI_NS, GeolocationHint.DEFAULT_ELEMENT_LOCAL_NAME,
                SAMLConstants.SAML20MDUI_PREFIX);
    }

    /** {@inheritDoc} */
    public GeolocationHint buildObject(String namespaceURI, String localName, String namespacePrefix) {
        return new GeolocationHintImpl(namespaceURI, localName, namespacePrefix);
    }
}

==> opensaml-saml-impl-3.4.5-sources.jar: org/opensaml/saml/ext/saml2mdui/impl/GeolocationHintBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.ext.saml2mdui.impl;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.saml.common.xml.SAMLConstants;
import org.opensaml.saml.ext.saml2mdui.GeolocationHint;

/**
 * Builder of {@link GeolocationHint} objects.
 */
public class GeolocationHintBuilder extends AbstractSAMLObjectBuilder<GeolocationHint> {

    /**
     * Constructor.
     */
    public GeolocationHintBuilder() {

    }

    /** {@inheritDoc} */
    public GeolocationHint buildObject() {
        return buildObject(SAMLConstants.SAML20MDUI_NS, GeolocationHint.DEFAULT_ELEMENT_LOCAL_NAME,
                SAMLConstants.SAML20MDUI_PREFIX);
    }

    /** {@inheritDoc} */
    public GeolocationHint buildObject(final String namespaceURI, final String localName,
            final String namespacePrefix) {
        return new GeolocationHintImpl(namespaceURI, localName, namespacePrefix);
    }
}
